/***************************************************************************
 *            matrix_exp.h
 *
 *  Thu Jun 18 12:51:16 2009
 *  Copyright  2009  Sandro Dias Pinto Vitenti
 *  <sandro@isoftware.com.br>
 ****************************************************************************/
/*
 * numcosmo
 * Copyright (C) Sandro Dias Pinto Vitenti 2012 <sandro@lapsandro>
 * numcosmo is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * numcosmo is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _NC_MAXTRIX_EXP_H
#define _NC_MAXTRIX_EXP_H

#include <glib.h>
#include <glib-object.h>
#include <numcosmo/build_cfg.h>

#ifndef NUMCOSMO_GIR_SCAN
#include <gsl/gsl_matrix.h>
#endif /* NUMCOSMO_GIR_SCAN */

G_BEGIN_DECLS

void ncm_matrix_exp_2x2 (gsl_matrix *B, gsl_matrix *exp_B);

G_END_DECLS

#endif /* _NC_MAXTRIX_EXP_H */
